@@ -1,7 +1,7 @@
 /** @type {import('@docusaurus/types').DocusaurusConfig} */
 module.exports = {
-  title: 'Atlas',
-  tagline: 'Manage your data',
+  title: 'Atlas | Open-source database schema management tool',
+  tagline: 'Manage your database schemas with Atlas CLI',
   url: 'https://atlasgo.io',
   baseUrl: '/',
   onBrokenLinks: 'throw',
@@ -9,6 +9,7 @@ module.exports = {
   organizationName: 'ariga',
   projectName: 'atlas',
   themeConfig: {
+    image: "https://atlas-og-img.vercel.app/**Atlas%20%7C**%20Open-source%20database%20schema%20management.png?theme=dark",
     prism: {
       additionalLanguages: ['hcl'],
       magicComments: [
@@ -59,8 +60,8 @@ module.exports = {
           position: 'left',
         },
         {
-          to: 'knowledge',
-          label: 'Knowledge Center',
+          to: 'guides',
+          label: 'Guides',
           position: 'left',
         },
         {
@@ -77,10 +78,10 @@ module.exports = {
           "title": "Docs",
           "items": [
             {"label": "Getting Started", "to": "getting-started"},
-            {"label": "Data Definition Language ", "to": "concepts/ddl"},
+            {"label": "Data Definition Language ", "to": "guides/ddl"},
             {"label": "CLI Reference", "to": "cli-reference"},
             {"label": "Blog", "to": "blog"},
-            {"label": "Knowledge Center", "to": "knowledge"},
+            {"label": "Guides", "to": "guides"},
             {"label": "About", "to": "about"},
             {"label": "GoDoc", "to": "https://pkg.go.dev/ariga.io/atlas"},
           ]
@@ -93,6 +94,14 @@ module.exports = {
             {"label": "Twitter", "to": "https://twitter.com/ariga_io"}
           ]
         },
+        {
+          "title": "Integrations",
+          "items": [
+            {"label": "GitHub Actions", "to": "/integrations/github-actions"},
+            {"label": "Terraform", "to": "/integrations/terraform-provider"},
+            {"label": "Go API", "to": "/integrations/go-api"}
+          ]
+        },
         {
           "title": "Legal",
           "items": [
@@ -147,8 +156,8 @@ module.exports = {
             from: '/dev-database',
           },
           {
-            to: '/concepts/ddl',
-            from: '/ddl/intro',
+            to: '/guides/ddl',
+            from: ['/ddl/intro', '/concepts/ddl'],
           },
           {
             to: '/atlas-schema/input-variables',
@@ -166,6 +175,26 @@ module.exports = {
             to: '/atlas-schema/sql-resources',
             from: '/ddl/sql',
           },
+          {
+            to: '/guides',
+            from: '/knowledge',
+          },
+          {
+            to: '/guides/mysql/generated-columns',
+            from: '/knowledge/mysql/generated-columns',
+          },
+          {
+            to: '/guides/postgres/partial-indexes',
+            from: '/knowledge/postgres/partial-indexes',
+          },
+          {
+            to: '/guides/postgres/serial-columns',
+            from: '/knowledge/postgres/serial-columns',
+          },
+          {
+            to: '/guides/ddl',
+            from: '/knowledge/ddl',
+          },
         ],
       },
     ],
