@@ -205,7 +205,7 @@ func testCLIMigrateApplyBC(t T, dialect string) {
 		"--url", t.url(""),
 	).CombinedOutput()
 	require.NoError(t, err, string(out))
-	require.Contains(t, string(out), "The migration directory is synced with the database")
+	require.Equal(t, "No migration files to execute\n", string(out))
 
 	// Connection to schema without flag will error.
 	out, err = exec.Command(
@@ -226,7 +226,7 @@ func testCLIMigrateApplyBC(t T, dialect string) {
 		"--revisions-schema", "atlas_schema_revisions",
 	).CombinedOutput()
 	require.NoError(t, err)
-	require.Contains(t, string(out), "The migration directory is synced with the database")
+	require.Equal(t, "No migration files to execute\n", string(out))
 
 	// Providing the flag to the schema instead will work as well.
 	t.migrate(
@@ -241,7 +241,7 @@ func testCLIMigrateApplyBC(t T, dialect string) {
 		"--revisions-schema", "bc_test",
 	).CombinedOutput()
 	require.NoError(t, err, string(out))
-	require.NotContains(t, string(out), "The migration directory is synced with the database")
+	require.NotContains(t, string(out), "No migration files to execute\n")
 
 	// Consecutive attempts do not need the flag anymore.
 	out, err = exec.Command(
@@ -251,7 +251,7 @@ func testCLIMigrateApplyBC(t T, dialect string) {
 		"--url", t.url("bc_test"),
 	).CombinedOutput()
 	require.NoError(t, err)
-	require.Contains(t, string(out), "The migration directory is synced with the database")
+	require.Equal(t, "No migration files to execute\n", string(out))
 
 	// Last, if bound to schema and no "old" behavior extra schema does
 	// exist, the revision table will be saved in the connected one.
@@ -493,6 +493,78 @@ func testCLISchemaApplyAutoApprove(t T, h string, dsn string, args ...string) {
 	require.NotNil(t, u)
 }
 
+func testCLISchemaApplyFromMigrationDir(t T) {
+	const (
+		dbname  = "apply_migration_dir"
+		devname = dbname + "_dev"
+	)
+	t.dropSchemas(dbname, devname)
+	t.migrate(&schema.AddSchema{S: schema.New(dbname)}, &schema.AddSchema{S: schema.New(devname)})
+	defer t.migrate(&schema.DropSchema{S: schema.New(dbname)}, &schema.DropSchema{S: schema.New(devname)})
+
+	users, err := t.driver().SchemaDiff(schema.New(""), schema.New("").AddTables(t.users()))
+	require.NoError(t, err)
+	usersT := t.users()
+	usersT.Name = "users_2"
+	users2, err := t.driver().SchemaDiff(schema.New(""), schema.New("").AddTables(usersT))
+	require.NoError(t, err)
+
+	addUsers, err := t.driver().PlanChanges(context.Background(), "", users)
+	require.NoError(t, err)
+	addUsers2, err := t.driver().PlanChanges(context.Background(), "", users2)
+	require.NoError(t, err)
+
+	var (
+		fn = func(c []*migrate.Change) string {
+			var buf strings.Builder
+			for _, c := range c {
+				buf.WriteString(c.Cmd)
+				buf.WriteString("\n")
+			}
+			return buf.String()
+		}
+		one = fn(addUsers.Changes)
+		two = fn(addUsers2.Changes)
+	)
+
+	p := t.TempDir()
+	require.NoError(t, os.WriteFile(filepath.Join(p, "1.sql"), []byte(one), 0644))
+	require.NoError(t, os.WriteFile(filepath.Join(p, "2.sql"), []byte(two), 0644))
+
+	require.NoError(t, initCLI())
+	require.NoError(t, exec.Command(
+		"go", "run", "ariga.io/atlas/cmd/atlas",
+		"migrate", "hash",
+		"--dir", "file://"+p,
+	).Run())
+
+	// All versions - must contain all migration files.
+	out, err := exec.Command(
+		"go", "run", "ariga.io/atlas/cmd/atlas",
+		"schema", "apply",
+		"-u", t.url(dbname),
+		"--to", "file://"+p,
+		"--dev-url", t.url(devname),
+		"--dry-run",
+	).CombinedOutput()
+	require.NoError(t, err)
+	require.Contains(t, string(out), one)
+	require.Contains(t, string(out), two)
+
+	// One version - must contain only file one.
+	out, err = exec.Command(
+		"go", "run", "ariga.io/atlas/cmd/atlas",
+		"schema", "apply",
+		"-u", t.url(dbname),
+		"--to", "file://"+p+"?version=1",
+		"--dev-url", t.url(devname),
+		"--dry-run",
+	).CombinedOutput()
+	require.NoError(t, err)
+	require.Contains(t, string(out), one)
+	require.NotContains(t, string(out), two)
+}
+
 func testCLISchemaDiff(t T, dsn string) {
 	err := initCLI()
 
@@ -648,6 +720,22 @@ func (r *rrw) ReadRevision(_ context.Context, v string) (*migrate.Revision, erro
 	return nil, migrate.ErrRevisionNotExist
 }
 
+func (r *rrw) DeleteRevision(_ context.Context, v string) error {
+	i := -1
+	for j, r := range *r {
+		if r.Version == v {
+			i = j
+			break
+		}
+	}
+	if i == -1 {
+		return nil
+	}
+	copy((*r)[i:], (*r)[i+1:])
+	*r = (*r)[:len(*r)-1]
+	return nil
+}
+
 func (r *rrw) ReadRevisions(context.Context) ([]*migrate.Revision, error) {
 	return *r, nil
 }
@@ -656,6 +744,8 @@ func (r *rrw) clean() {
 	*r = []*migrate.Revision{}
 }
 
+var _ migrate.RevisionReadWriter = (*rrw)(nil)
+
 func buildCmd(t *testing.T) (string, error) {
 	td := t.TempDir()
 	if b, err := exec.Command("go", "build", "-o", td, "ariga.io/atlas/cmd/atlas").CombinedOutput(); err != nil {
