@@ -86,7 +86,7 @@ func findTableSpec(tableSpecs []*sqlspec.Table, schemaName, tableName string) (*
 // ForeignKeySpecs into ForeignKeys, as the target tables do not necessarily exist in the schema
 // at this point. Instead, the linking is done by the Schema function.
 func Table(spec *sqlspec.Table, parent *schema.Schema, convertColumn ConvertColumnFunc,
-	convertPk ConvertPrimaryKeyFunc, convertIndex ConvertIndexFunc, convertCheck ConvertCheckFunc) (*schema.Table, error) {
+	convertPK ConvertPrimaryKeyFunc, convertIndex ConvertIndexFunc, convertCheck ConvertCheckFunc) (*schema.Table, error) {
 	tbl := &schema.Table{
 		Name:   spec.Name,
 		Schema: parent,
@@ -99,7 +99,7 @@ func Table(spec *sqlspec.Table, parent *schema.Schema, convertColumn ConvertColu
 		tbl.Columns = append(tbl.Columns, col)
 	}
 	if spec.PrimaryKey != nil {
-		pk, err := convertPk(spec.PrimaryKey, tbl)
+		pk, err := convertPK(spec.PrimaryKey, tbl)
 		if err != nil {
 			return nil, err
 		}
@@ -456,10 +456,6 @@ func normalizeQuotes(s string) (string, error) {
 func FromIndex(idx *schema.Index, partFns ...func(*schema.IndexPart, *sqlspec.IndexPart)) (*sqlspec.Index, error) {
 	spec := &sqlspec.Index{Name: idx.Name, Unique: idx.Unique}
 	convertCommentFromSchema(idx.Attrs, &spec.Extra.Attrs)
-	if parts, ok := columnsOnly(idx); ok {
-		spec.Columns = parts
-		return spec, nil
-	}
 	spec.Parts = make([]*sqlspec.IndexPart, len(idx.Parts))
 	for i, p := range idx.Parts {
 		part := &sqlspec.IndexPart{Desc: p.Desc}
@@ -482,18 +478,23 @@ func FromIndex(idx *schema.Index, partFns ...func(*schema.IndexPart, *sqlspec.In
 		}
 		spec.Parts[i] = part
 	}
+	if parts, ok := columnsOnly(spec.Parts); ok {
+		spec.Parts = nil
+		spec.Columns = parts
+		return spec, nil
+	}
 	return spec, nil
 }
 
-func columnsOnly(idx *schema.Index) ([]*schemahcl.Ref, bool) {
-	parts := make([]*schemahcl.Ref, len(idx.Parts))
-	for i, p := range idx.Parts {
-		if p.C == nil || p.Desc {
+func columnsOnly(parts []*sqlspec.IndexPart) ([]*schemahcl.Ref, bool) {
+	columns := make([]*schemahcl.Ref, len(parts))
+	for i, p := range parts {
+		if p.Desc || p.Column == nil || len(p.Extra.Attrs) != 0 {
 			return nil, false
 		}
-		parts[i] = ColumnRef(p.C.Name)
+		columns[i] = p.Column
 	}
-	return parts, true
+	return columns, true
 }
 
 // FromForeignKey converts schema.ForeignKey to sqlspec.ForeignKey.
@@ -506,11 +507,7 @@ func FromForeignKey(s *schema.ForeignKey) (*sqlspec.ForeignKey, error) {
 	for _, v := range s.RefColumns {
 		ref := ColumnRef(v.Name)
 		if s.Table != s.RefTable {
-			if s.Table.Schema == s.RefTable.Schema {
-				ref = externalColRef(v.Name, s.RefTable.Name)
-			} else {
-				ref = crossSchemaColRef(v.Name, s.RefTable.Name, s.RefTable.Schema.Name)
-			}
+			ref = externalColRef(v.Name, s.RefTable.Name)
 		}
 		r = append(r, ref)
 	}
@@ -635,7 +632,7 @@ func externalColRef(cName string, tName string) *schemahcl.Ref {
 	return &schemahcl.Ref{V: "$table." + tName + ".$column." + cName}
 }
 
-func crossSchemaColRef(cName, tName, sName string) *schemahcl.Ref {
+func qualifiedExternalColRef(cName, tName, sName string) *schemahcl.Ref {
 	return &schemahcl.Ref{V: "$table." + sName + "." + tName + ".$column." + cName}
 }
 
