@@ -245,18 +245,28 @@ func columnType(c *columnDesc) (schema.Type, error) {
 			if err != nil {
 				return nil, err
 			}
+			if c.elemtyp == "e" {
+				// Override the element type in
+				// case it is an enum.
+				tt = newEnumType(t, c.typelem)
+			}
 			typ.(*ArrayType).Type = tt
 		}
 	case TypeUserDefined:
 		typ = &UserDefinedType{T: c.fmtype}
+	default:
+		typ = &schema.UnsupportedType{T: t}
+	}
+	switch c.typtype {
+	case "e":
 		// The `typtype` column is set to 'e' for enum types, and the
 		// values are filled in batch after the rows above is closed.
 		// https://postgresql.org/docs/current/catalog-pg-type.html
-		if c.typtype == "e" {
-			typ = newEnumType(c.fmtype, c.typid)
-		}
-	default:
-		typ = &schema.UnsupportedType{T: t}
+		typ = newEnumType(c.fmtype, c.typid)
+	case "d":
+		// Use user-defined for domain types as we do not
+		// support their creation at this stage.
+		typ = &UserDefinedType{T: c.fmtype}
 	}
 	return typ, nil
 }
@@ -293,6 +303,8 @@ type columnDesc struct {
 	fmtype        string // pg_catalog.format_type
 	size          int64  // character_maximum_length
 	typtype       string // pg_type.typtype
+	typelem       int64  // pg_type.typelem
+	elemtyp       string // pg_type.typtype of the array element type above.
 	typid         int64  // pg_type.oid
 	precision     int64
 	timePrecision *int64
