@@ -15,7 +15,9 @@ import (
 	"ariga.io/atlas/sql/internal/sqlx"
 	"ariga.io/atlas/sql/schema"
 	"ariga.io/atlas/sql/sqlspec"
+
 	"github.com/hashicorp/hcl/v2/hclparse"
+	"github.com/zclconf/go-cty/cty"
 )
 
 type (
@@ -38,7 +40,7 @@ func init() {
 }
 
 // evalSpec evaluates an Atlas DDL document into v using the input.
-func evalSpec(p *hclparse.Parser, v any, input map[string]string) error {
+func evalSpec(p *hclparse.Parser, v any, input map[string]cty.Value) error {
 	var d doc
 	if err := hclState.Eval(p, &d, input); err != nil {
 		return err
@@ -318,6 +320,22 @@ func convertIndex(spec *sqlspec.Index, t *schema.Table) (*schema.Index, error) {
 		}
 		idx.Attrs = append(idx.Attrs, &IndexStorageParams{PagesPerRange: p})
 	}
+	if attr, ok := spec.Attr("include"); ok {
+		refs, err := attr.Refs()
+		if err != nil {
+			return nil, err
+		}
+		if len(refs) == 0 {
+			return nil, fmt.Errorf("unexpected empty INCLUDE in index %q definition", spec.Name)
+		}
+		include := make([]*schema.Column, len(refs))
+		for i, r := range refs {
+			if include[i], err = specutil.ColumnByRef(t, r); err != nil {
+				return nil, err
+			}
+		}
+		idx.Attrs = append(idx.Attrs, &IndexInclude{Columns: include})
+	}
 	return idx, nil
 }
 
@@ -482,6 +500,16 @@ func indexSpec(idx *schema.Index) (*sqlspec.Index, error) {
 	if i := (IndexType{}); sqlx.Has(idx.Attrs, &i) && i.T != IndexTypeBTree {
 		spec.Extra.Attrs = append(spec.Extra.Attrs, specutil.VarAttr("type", strings.ToUpper(i.T)))
 	}
+	if i := (IndexInclude{}); sqlx.Has(idx.Attrs, &i) && len(i.Columns) > 0 {
+		attr := &schemahcl.ListValue{}
+		for _, c := range i.Columns {
+			attr.V = append(attr.V, specutil.ColumnRef(c.Name))
+		}
+		spec.Extra.Attrs = append(spec.Extra.Attrs, &schemahcl.Attr{
+			K: "include",
+			V: attr,
+		})
+	}
 	if i := (IndexPredicate{}); sqlx.Has(idx.Attrs, &i) && i.P != "" {
 		spec.Extra.Attrs = append(spec.Extra.Attrs, specutil.VarAttr("where", strconv.Quote(i.P)))
 	}
